@@ -9,7 +9,7 @@ class NetatalkConfigTest (BaseConfigTest):
 afp port=123
 
 [test]
-path=/home
+path=/home ;comment
 valid users=root
 ea=sys
 """
@@ -19,19 +19,18 @@ ea=sys
         "global": {
             "zeroconf": True,
             "cnid_listen": "localhost:4700",
-            "security": "user",
             "afp_port": "123",
-            "log_file": ""
         },
         "shares": [
             {
+                "comment": "comment",
                 "appledouble": "ea",
                 "name": "test",
                 "ea": "sys",
                 "valid_users": "root",
                 "cnid_scheme": "dbd",
                 "path": "/home",
-                "password": None
+                "password": '',
             }
         ]
     }
